@@ -49,25 +49,26 @@ import os
 import signal
 import sys
 import time
+from datetime import date
 
 try:
     from fcntl import ioctl
     from array import array
     import termios
-except ImportError:
+except ImportError:  # pragma: no cover
     pass
 
 try:
     from cStringIO import StringIO
-except ImportError:
+except ImportError:  # pragma: no cover
     from StringIO import StringIO
 
 from widgets import *
 
 __author__ = 'Rick van Hattem'
 __author_email__ = 'Rick.van.Hattem@Fawo.nl'
-__date__ = '2012-02-20'
-__version__ = '2.4.1'
+__date__ = str(date.today())
+__version__ = '2.5.0'
 
 
 class UnknownLength:
@@ -79,6 +80,7 @@ class ProgressBar(object):
     '''The ProgressBar class which updates and prints the bar.
 
     A common way of using it is like:
+
     >>> pbar = ProgressBar().start()
     >>> for i in range(100):
     ...     pbar.update(i+1)
@@ -87,6 +89,7 @@ class ProgressBar(object):
     >>> pbar.finish()
 
     You can also use a ProgressBar as an iterator:
+
     >>> progress = ProgressBar()
     >>> some_iterable = range(100)
     >>> for i in progress(some_iterable):
@@ -155,9 +158,9 @@ class ProgressBar(object):
                 self._handle_resize()
                 signal.signal(signal.SIGWINCH, self._handle_resize)
                 self.signal_set = True
-            except (SystemExit, KeyboardInterrupt):
+            except (SystemExit, KeyboardInterrupt):  # pragma: no cover
                 raise
-            except:
+            except:  # pragma: no cover
                 self.term_width = self._env_size()
 
         self.__iterable = None
@@ -285,10 +288,10 @@ class ProgressBar(object):
 
             self.currval = value
 
-        if not self._need_update():
-            return
         if self.start_time is None:
             raise RuntimeError('You must call "start" before calling "update"')
+        if not self._need_update():
+            return
 
         if self.redirect_stderr and sys.stderr.tell():
             self.fd.write('\r' + ' ' * self.term_width + '\r')
@@ -312,6 +315,7 @@ class ProgressBar(object):
         '''Starts measuring time, and prints the bar at 0%.
 
         It returns self so you can use it like this:
+
         >>> pbar = ProgressBar().start()
         >>> for i in range(100):
         ...    # do something
@@ -361,7 +365,3 @@ class ProgressBar(object):
             self._stdout.write(sys.stdout.getvalue())
             sys.stdout = self._stdout
 
-
-if __name__ == '__main__':
-    import doctest
-    doctest.testmod()
